@@ -61,6 +61,8 @@ GtkWidget       *gnome_db_grid_new_with_model (GdaDataModel *model);
 
 const gchar     *gnome_db_grid_get_title (GnomeDbGrid *grid);
 void             gnome_db_grid_set_title (GnomeDbGrid *grid, const gchar *title);
+void             gnome_db_grid_set_column_title (GnomeDbGrid *grid, gint col, const gchar *title);
+const gchar     *gnome_db_grid_get_column_title (GnomeDbGrid *grid, gint col);
 gboolean         gnome_db_grid_get_show_title (GnomeDbGrid *grid);
 void             gnome_db_grid_set_show_title (GnomeDbGrid *grid, gboolean show);
 void             gnome_db_grid_set_title_icon_from_file (GnomeDbGrid *grid, const gchar *file);
@@ -74,14 +76,21 @@ GList           *gnome_db_grid_get_selection (GnomeDbGrid *grid);
 void             gnome_db_grid_foreach_selected (GnomeDbGrid *grid,
 						 GnomeDbGridForeachFunc foreach_func,
 						 gpointer user_data);
+void             gnome_db_grid_select_row (GnomeDbGrid *grid, gint row);
 void             gnome_db_grid_select_all (GnomeDbGrid *grid);
 void             gnome_db_grid_unselect_all (GnomeDbGrid *grid);
 GtkSelectionMode gnome_db_grid_get_selection_mode (GnomeDbGrid *grid);
 void             gnome_db_grid_set_selection_mode (GnomeDbGrid *grid,
 						   GtkSelectionMode mode);
 
-void             gnome_db_grid_hide_column_titles (GnomeDbGrid *grid);
-void             gnome_db_grid_show_column_titles (GnomeDbGrid *grid);
+void             gnome_db_grid_set_column_titles_visible (GnomeDbGrid *grid, gboolean visible);
+gboolean         gnome_db_grid_get_column_titles_visible (GnomeDbGrid *grid);
+#define gnome_db_grid_show_column_titles(grid) \
+	(gnome_db_grid_set_column_titles_visible (grid, TRUE))
+#define gnome_db_grid_hide_column_titles(grid) \
+	(gnome_db_grid_set_column_titles_visible (grid, FALSE))
+void             gnome_db_grid_set_column_visible (GnomeDbGrid *grid, gint col, gboolean visible);
+gboolean         gnome_db_grid_get_column_visible (GnomeDbGrid *grid, gint col);
 
 gpointer         gnome_db_grid_get_row_data (GnomeDbGrid *grid, gint row);
 void             gnome_db_grid_set_row_data (GnomeDbGrid *grid, gint row, gpointer data);
